package com.halomobi.sdk;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.ComponentName;
import android.content.DialogInterface;
import android.content.Intent;
import android.graphics.Bitmap;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.webkit.WebResourceRequest;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.ImageView;

import com.halomobi.common.ConstantPool;
import com.halomobi.network.listeners.AdStateChangListener;
import com.halomobi.network.request.ad.bean.Ad;
import com.halomobi.network.request.ad.bean.AdParameter;
import com.halomobi.sdk.listener.BannerListener;
import com.halomobi.sdk.listener.InsertListener;
import com.halomobi.utils.LogUtils;
import com.halomobi.utils.PxUtil;
import com.halomobi.utils.WebViewUtils;

import java.util.List;

public class HMBannerAd {
    private HlAdParameter mHlParameter;
    private AdController adController;
    private AdParameter mAdParameter;
    private Activity mActivity;
    private BannerListener mListener;
    private boolean isShow;
    private boolean isReady;
    private double currentPrice = 0;
    private Ad mAdInfo;

    public HMBannerAd(Activity activity, HlAdParameter parameter, BannerListener listener) {
        mActivity = activity;
        isReady = true;
        isShow = true;
        mListener = listener;
        mHlParameter = parameter;
        adController = new AdController(activity);
        mAdParameter = new AdParameter(HaloAdSdk.mAppId, parameter, activity.getPackageName(), ConstantPool.AdType.BANNER);
    }

    public void loadAd() {
        adController.requestAd(mAdParameter, new AdStateChangListener() {
            @Override
            public void onStart() {

            }

            @Override
            public void onAdError(String errorMsg, int errorCode) {
                mListener.onAdError(errorMsg, errorCode);
            }

            @Override
            public void onAdReach(Ad adInfo) {
                currentPrice = adInfo.price;
                mAdInfo = adInfo;
                if (isReady) {
                    isReady = false;
                    mListener.onAdReady();
                }
            }

            @Override
            public void onNativeAdReach(List<Ad> adInfoList) {

            }
        });
    }

    public void showView(ViewGroup viewGroup) {
        showBannerAd(mActivity, mAdInfo, viewGroup);
    }

    private void showBannerAd(Activity activity, Ad adInfo, ViewGroup viewGroup) {
        LogUtils.e("===adInfo===" + adInfo.adm);
        activity.runOnUiThread(() -> {
            String adid = adInfo.adid;
            String adm = adInfo.adm.replace("${AUCTION_BID_ID}", adid);
            View inflate = LayoutInflater.from(activity).inflate(R.layout.hl_dialog_banner, null, false);
            final WebView mWebView = inflate.findViewById(R.id.webView);
            WebViewUtils utils = new WebViewUtils();
            utils.initWebView(activity, mWebView, adInfo);
            mWebView.loadData(adm, "text/html", "UTF-8");
            viewGroup.addView(inflate);
            mWebView.setWebViewClient(new WebViewClient() {
                @Override
                public boolean shouldOverrideUrlLoading(WebView view, WebResourceRequest request) {
                    Log.e("11111", "===shouldOverrideUrlLoading===" + request.getUrl());
                    if (request.getUrl().toString().contains("halomobi.com/api/cpi/click")) {
                        final Intent intent = new Intent();
                        intent.setAction(Intent.ACTION_VIEW);
                        intent.setData(request.getUrl());
                        // 注意此处的判断intent.resolveActivity()可以返回显示该Intent的Activity对应的组件名
                        // 官方解释 : Name of the component implementing an activity that can display the intent
                        if (intent.resolveActivity(mActivity.getPackageManager()) != null) {
                            mActivity.startActivity(Intent.createChooser(intent, "请选择浏览器"));
                        }
                    }
                    return true;
                }

                @Override
                public void onPageStarted(WebView view, String url, Bitmap favicon) {
                    super.onPageStarted(view, url, favicon);

                }

                @Override
                public void onPageFinished(WebView view, String url) {
                    super.onPageFinished(view, url);
                    Log.e("11111", "===onPageFinished===" + url);
                    if (isShow) {
                        isShow = false;
                        mListener.onDisplayAd();
                    }
                }
            });
        });
    }

    public double getEcpm() {
        return currentPrice;
    }
}
